@@ -10,8 +10,8 @@ class DrugIndicationResourceSchema(Schema):
 
     id = fields.Integer(dump_only=True)
     set_id = fields.String(validate=not_blank, required=True)
-    lowercase_indication = fields.String(validate=not_blank, required=True)
-    indication = fields.String(validate=not_blank, required=True)
+    lowercase_indication = fields.String(allow_none=True)
+    indication = fields.String(allow_none=True)
     updated_at = fields.DateTime()
 
 
@@ -20,13 +20,13 @@ class DrugIndicationQueryParamsSchema(Schema):
 
     id = fields.Integer()
     set_id = fields.String(validate=not_blank)
-    lowercase_indication = fields.String(validate=not_blank)
-    indication = fields.String(validate=not_blank)
+    lowercase_indication = fields.String(allow_none=True)
+    indication = fields.String(allow_none=True)
 
 
 class DrugIndicationPatchSchema(Schema):
     not_blank = validate.Length(min=1, error='Field cannot be blank')
 
     set_id = fields.String(validate=not_blank)
-    lowercase_indication = fields.String(validate=not_blank)
-    indication = fields.String(validate=not_blank)
+    lowercase_indication = fields.String(allow_none=True)
+    indication = fields.String(allow_none=True)
